#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell
version:              0.5.0.2
visibility:           public
id:                   chell-0.5.0.2-E4gskuPJdljAKngfBJ0Hwo
key:                  chell-0.5.0.2-E4gskuPJdljAKngfBJ0Hwo
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing.
    It natively supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

category:             Testing
abi:                  c691fe3fa23544e387ee0848203eaa20
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chell-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell
hs-libraries:         HSchell-0.5.0.2-E4gskuPJdljAKngfBJ0Hwo
depends:
    ansi-terminal-1.1-5nZVpYMolxlDp5iPgkZNkW base-4.18.2.1
    bytestring-0.11.5.3 options-1.2.1.2-LuDwNQksf23D84KSjvt6ZJ
    patience-0.3-FGve9R2EZzO566jluhwsHH
    random-1.2.1.3-5FoUrrA3875KkJXWnCWBBA template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

